/***************************
  DIO24-ARD Write Example
****************************/

// Must specify the Arduino SPI library
#include <SPI.h>

// Declare program constants
const int  DIO24_Select = 10;   // Pin used as board enable, *** MUST MATCH J2 SETTING ON DIO24-ARD
const byte CMD_WR = 0x00;       // Write Command

// Declare program variables
byte  porta_wr_value;  // Holds 8-bit data to be written to porta
byte  portb_wr_value;  // Holds 8-bit data to be written to portb
byte  portc_wr_value;  // Holds 8-bit data to be written to portc


// Perform Program Initialization
void setup() {
   SPI.begin();                           // Initialize SPI
   pinMode(DIO24_Select, OUTPUT);         // Set DIO24_Select as an output
   digitalWrite(DIO24_Select, HIGH);      // De-Select the DIO24-ARD
}

// --- This is the Main Loop, repeats indefinitely
void loop() {
 
   // Pre-load the variables with data to be written to the three ports.
   // Note: These port values are hard-coded (non-changing) to match the DIO24-ARD documentation.
   // In an actual Arduino sketch their values would change according to the application and how the DIO24-ARD is used.  
   porta_wr_value = 0x87;  // This value will be written to PORTA
   portb_wr_value = 0x12;  // This value will be written to PORTB
   portc_wr_value = 0x7e;  // This value will be written to PORTC
   
   // Write variable data to the three ports
   digitalWrite(DIO24_Select, LOW);      // Step 1, Select the DIO24-ARD 
   SPI.transfer(CMD_WR);                 // Step 2, Send 1st byte: Write Command, discard returned byte
   SPI.transfer(porta_wr_value);         // Step 3, Send 2nd byte: Data to be written to PORTA, discard returned byte unless needed
   SPI.transfer(portb_wr_value);         // Step 4, Send 3rd byte: Data to be written to PORTB, discard returned byte unless needed
   SPI.transfer(portc_wr_value);         // Step 5, Send 4th byte: Data to be written to PORTC, discard returned byte unless needed
   digitalWrite(DIO24_Select, HIGH);     // Step 6, De-Select the DIO24-ARD 
}


